@@ -5,5 +5,7 @@ from .monochromatic_simulator import MonochromaticField
 from . import colour_functions as cf
 from .polynomials import zernike_polynomial
 from .holography import FourierPhaseRetrieval, CustomPhaseRetrieval
+from .diffractive_elements import *
+from .light_sources import *
 
 from .util.constants import *
